ngHandsontable.Angular version of Handontable library
Description: Excel-like data grid with HTML & JavaScript

Star Fork

ngHandsontable is the AngularJS version of the Handsontable data grid

This demo page shows usage usage examples. All features of Handsontable are supported.

## Static configuration with dynamic data

The main directive for ngHandsontable is `hot-table`

You can put all your settings in `settings="{colHeaders: colHeaders,
contextMenu: true }"` attribute or in separated attributes, e.g. `minSpareRows="minSpareRows"`, `rowHeaders="false"`.

## Dynamic configuration with dynamic data

This example uses a dynamic `columns` configuration that changes every 3 seconds!

It is bound to the same data source as the first instance on this page.

## Data binding

The below `input` field is bound to the `address` property of the first data row.

Address
Releases Source Issues